AIDataFilter - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# AIDataFilter

class inmydata.StructuredData.AIDataFilter(Field: str, ConditionOperator: ConditionOperator, LogicalOperator: LogicalOperator, Value, StartGroup: int, EndGroup: int, CaseInsensitive: bool)

  Bases: `object`

  A class representing a filter for querying data in the inmydata platform. This class encapsulates the details of a filter, including the field to filter on, the condition operator, the logical operator, the value to filter by, and grouping information.

  LogicalOperator

    The logical operator to combine this filter with others.

    Type:

      LogicalOperator

  Field

    The field to filter on.

    Type:

      str

  ConditionOperator

    The condition operator to apply to the filter.

    Type:

      ConditionOperator

  Value

    The value to filter by.

  StartGroup

    The starting group index for this filter.

    Type:

      int

  EndGroup

    The ending group index for this filter.

    Type:

      int

  CaseInsensitive

    Whether the filter should be case insensitive.

    Type:

      bool

  ## Members

  __init__(Field: str, ConditionOperator: ConditionOperator, LogicalOperator: LogicalOperator, Value, StartGroup: int, EndGroup: int, CaseInsensitive: bool)

    Initializes the AIDataFilter with the specified field, condition operator, logical operator, value, and grouping information.

    Parameters:

      - Field (str) – The field to filter on.

      - ConditionOperator (ConditionOperator) – The condition operator to apply to the filter.

      - LogicalOperator (LogicalOperator) – The logical operator to combine this filter with others.

      - Value – The value to filter by.

      - StartGroup (int) – The starting group index for this filter.

      - EndGroup (int) – The ending group index for this filter.

      - CaseInsensitive (bool) – Whether the filter should be case insensitive.

  to_dict()

    Converts the AIDataFilter instance to a dictionary representation.

    Returns:

      A dictionary representation of the AIDataFilter instance.

    Return type:

      dict